MsgVerifyInvariant class

Constructors

MsgVerifyInvariant(String sender, String invariantModuleName, String invariantRoute)

Properties

hashCode → int
The hash code for this object.
no setterinherited
invariantModuleName → String
final
invariantRoute → String
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String
final
sequenceNumber ↔ double?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgVerifyInvariantDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited