CoinsExtensions class

Constructors

CoinsExtensions()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convertToString(List<Coin> coins) → String
fromAmino(List<CoinAminoArgs> coins) → List<Coin>
fromData(List<CoinDataArgs> coins) → List<Coin>
fromJSON(List<CoinJSON> coins) → List<Coin>
fromString(String str) → List<Coin>
getDenoms(List<Coin> coins) → List<String>
toAmino(List<Coin> coins) → List<CoinAminoArgs>
toData(List<Coin> coins) → List<CoinDataArgs>
toDecCoins(List<Coin> coins) → List<Coin>
toIntCeilCoins(List<Coin> coins) → List<Coin>
toIntCoins(List<Coin> coins) → List<Coin>
toJSON(List<Coin> coins) → List<CoinJSON>

Constants

COINS_FROM_STRING_REGEX → const String