MsgVote class

Constructors

MsgVote(double proposal_id, String voter, VoteOption option)

Properties

hashCode → int
The hash code for this object.
no setterinherited
option → VoteOption
final
proposal_id → double
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
voter → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgVoteAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgVoteDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(MsgVoteAminoArgs data) → MsgVote
fromData(MsgVoteDataArgs data) → MsgVote