MsgVoteWeighted class

Constructors

MsgVoteWeighted(double proposal_id, String voter, List<WeightedVoteOption> option)

Properties

hashCode → int
The hash code for this object.
no setterinherited
option ↔ List<WeightedVoteOption>
getter/setter pair
proposal_id ↔ double
getter/setter pair
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
voter ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgVoteWeightedAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgVoteWeightedDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited