CommonProposalArgs class

Constructors

CommonProposalArgs()

Properties

content ↔ ProposalContent?
getter/setter pair
deposit_End_Time ↔ String?
getter/setter pair
final_tally_result ↔ FinalTallyResult?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ProposalStatus?
getter/setter pair
submit_Time ↔ String?
getter/setter pair
total_Deposit ↔ List<Coin>?
getter/setter pair
voting_End_Time ↔ String?
getter/setter pair
voting_Start_Time ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited