Vote class

Constructors

Vote(double proposal_id, String voter, List<WeightedVoteOption> options)

Properties

hashCode → int
The hash code for this object.
no setterinherited
options ↔ List<WeightedVoteOption>
getter/setter pair
proposal_id ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voter ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → VoteAminoArgs
toData() → VoteDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(VoteAminoArgs data) → Vote
fromData(VoteDataArgs data) → Vote
fromJSON(VotesJSON data) → Vote