VoteDataArgs class

Inheritance

Constructors

VoteDataArgs()

Properties

hashCode → int
The hash code for this object.
no setterinherited
options ↔ List<WeightedVoteOption>?
getter/setter pairinherited
proposal_id ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voter ↔ String?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited