WeightedVoteOption class

Constructors

WeightedVoteOption(VoteOption option, double weight)

Properties

hashCode → int
The hash code for this object.
no setterinherited
option → VoteOption
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → WeightedVoteAminoArgs
toData() → WeightedVoteDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited