Channel class

Constructors

Channel(State state, Order ordering, Counterparty counterParty, List<String> connection_hops, String version)

Properties

connection_hops → List<String>
final
counterParty → Counterparty
final
hashCode → int
The hash code for this object.
no setterinherited
ordering → Order
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → State
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → ChannelAminoArgs
ToData() → ChannelDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAmino(ChannelAminoArgs data) → Channel
fromData(ChannelDataArgs data) → Channel