MsgChannelOpenConfirm class

Constructors

MsgChannelOpenConfirm(String port_id, String channel_id, String proof_ack, Height? proof_height, String signer)

Properties

channel_id → String
final
hashCode → int
The hash code for this object.
no setterinherited
port_id → String
final
proof_ack → String
final
proof_height → Height?
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
signer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgChannelOpenConfirmDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited