MsgRecvPacket class

Constructors

MsgRecvPacket(Packet packet, String proof_commitment, Height proof_height, String signer)

Properties

hashCode → int
The hash code for this object.
no setterinherited
packet → Packet
final
proof_commitment → String
final
proof_height → Height
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
signer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgRecvPacketDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromData(MsgRecvPacketDataArgs data) → MsgRecvPacket