MsgTimeout class

Constructors

MsgTimeout(Packet packet, String proof_unreceived, Height proof_height, double next_sequence_recv, String signer)

Properties

hashCode → int
The hash code for this object.
no setterinherited
next_sequence_recv → double
final
packet → Packet
final
proof_height → Height
final
proof_unreceived → String
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
signer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgTimeoutDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromData(MsgTimeoutDataArgs data) → MsgTimeout