Packet class

Constructors

Packet(double sequence, String source_port, String source_channel, String destination_port, String destination_channel, String data, Height timeout_height, double timeout_timestamp)

Properties

data → String
final
destination_channel → String
final
destination_port → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → double
final
source_channel → String
final
source_port → String
final
timeout_height → Height
final
timeout_timestamp → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() → PacketDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromData(PacketDataArgs data) → Packet