PacketCommonArgs class

Implementers

Constructors

PacketCommonArgs()

Properties

data ↔ String?
getter/setter pair
destination_channel ↔ String?
getter/setter pair
destination_port ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence ↔ double?
getter/setter pair
source_channel ↔ String?
getter/setter pair
source_port ↔ String?
getter/setter pair
timeout_timeStamp ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited