PacketDataArgs class

Inheritance

Constructors

PacketDataArgs()

Properties

data ↔ String?
getter/setter pairinherited
destination_channel ↔ String?
getter/setter pairinherited
destination_port ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence ↔ double?
getter/setter pairinherited
source_channel ↔ String?
getter/setter pairinherited
source_port ↔ String?
getter/setter pairinherited
timeout_height ↔ HeightDataArgs?
getter/setter pair
timeout_timeStamp ↔ String?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited