MsgConnectionOpenAck class

Constructors

MsgConnectionOpenAck(String connection_id, String counterparty_connection_id, Version version, Any client_state, Height proof_height, String proof_try, String proof_client, String proof_consensus, Height consensus_height, String signer)

Properties

client_state → Any
final
connection_id → String
final
consensus_height → Height
final
counterparty_connection_id → String
final
hashCode → int
The hash code for this object.
no setterinherited
proof_client → String
final
proof_consensus → String
final
proof_height → Height
final
proof_try → String
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
signer → String
final
version → Version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toArray() → List<SignerData>
inherited
toData() → MsgConnectionOpenAckDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited