MsgConnectionOpenAckDataArgs class

Properties

client_State ↔ Any?
getter/setter pair
connection_id ↔ String?
getter/setter pair
consensus_Height ↔ HeightDataArgs?
getter/setter pair
counterparty_Connection_Id ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
proof_Client ↔ String?
getter/setter pair
proof_Consensus ↔ String?
getter/setter pair
proof_Height ↔ HeightDataArgs?
getter/setter pair
proof_Try ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signer ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair
version ↔ VersionDataArgs?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited