MsgAggregateExchangeRatePrevote class

Constructors

MsgAggregateExchangeRatePrevote(String hash, String feeder, String validator)

Properties

feeder ↔ String
getter/setter pair
hash ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited
validator ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgAggregateExchangeRatePrevoteAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgAggregateExchangeRatePrevoteDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited