MsgCreateValidatorValueAminoArgs class

Properties

commission ↔ CommissionRatesCommonArgs?
getter/setter pair
delegator_Address ↔ String?
getter/setter pair
description ↔ ValidatorDescriptionCommonArgs?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
min_Self_Delegation ↔ String?
getter/setter pair
pubkey ↔ ValConsKeyAminoArgs?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validator_Address ↔ String?
getter/setter pair
value ↔ CoinAminoArgs?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited