MsgExecuteContract class

Constructors

MsgExecuteContract(String sender, String contract, String execute_msg, List<Coin> coins)

Properties

coins → List<Coin>
final
contract → String
final
execute_msg → String
final
hashCode → int
The hash code for this object.
no setterinherited
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String
final
sequenceNumber ↔ double?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgExecuteContractAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgExecuteContractDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited