MsgMigrateContract class

Constructors

MsgMigrateContract(String admin, String contract, double new_code_id, String migrate_msg)

Properties

admin → String
final
contract → String
final
hashCode → int
The hash code for this object.
no setterinherited
migrate_msg → String
final
new_code_id → double
final
publicKey ↔ KeysDto?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber ↔ double?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAmino() → MsgMigrateContractAminoArgs
toArray() → List<SignerData>
inherited
toData() → MsgMigrateContractDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited