TxLog class

Constructors

TxLog(double msg_index, String log, List<Event> events)

Properties

events → List<Event>
final
eventsByType ↔ EventsByType?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
log → String
final
msg_index → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toData() → TxLogDataArgs
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromData(TxLogDataArgs data) → TxLog